@@ -567,13 +567,14 @@ class RPC:
                         if m_count < len(kwargs):
                             params_data += "&"
                     else:
-                        m_uri.replace("{pk}", parse.quote(
+                        m_uri= m_uri.replace("{pk}", parse.quote(
                             str(kwargs[param['key']])))
-                if m_method == u"GET" or m_method == u"DELETE":
-                    if m_uri.find('?'):
-                        m_uri += "&" + params_data
-                    else:
-                        m_uri += "?"+params_data
+                if params_data:
+                    if m_method == u"GET" or m_method == u"DELETE":
+                        if m_uri.find('?')>=0:
+                            m_uri += "&" + params_data
+                        else:
+                            m_uri += "?"+params_data
                 try:
                     if m_method == u"GET":
                         self._log(m_uri)
